==> dojo-1.9.4.tgz: package/cldr/nls/de/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Wochentag",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E, d.M.y",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"eraNarrow": [
		"v. Chr.",
		"n. Chr."
	],
	"dateFormatItem-yMM": "MM.y",
	"dayPeriods-format-wide-earlyMorning": "morgens",
	"dayPeriods-format-wide-morning": "vormittags",
	"days-format-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"dateFormat-long": "d. MMMM y",
	"months-format-wide": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember"
	],
	"dayPeriods-format-wide-evening": "abends",
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "nachm.",
	"dateFormat-full": "EEEE, d. MMMM y",
	"dateFormatItem-Md": "d.M.",
	"dayPeriods-format-wide-noon": "Mittag",
	"dateFormatItem-yMd": "d.M.y",
	"field-era": "Epoche",
	"dateFormatItem-yM": "M.y",
	"months-standAlone-wide": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "Jahr",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "Stunde",
	"dateFormatItem-MMdd": "dd.MM.",
	"months-format-abbr": [
		"Jan.",
		"Feb.",
		"Mär.",
		"Apr.",
		"Mai",
		"Juni",
		"Juli",
		"Aug.",
		"Sep.",
		"Okt.",
		"Nov.",
		"Dez."
	],
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "Heute",
	"field-day-relative+1": "Morgen",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "Übermorgen",
	"dateFormatItem-H": "HH 'Uhr'",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mär",
		"Apr",
		"Mai",
		"Jun",
		"Jul",
		"Aug",
		"Sep",
		"Okt",
		"Nov",
		"Dez"
	],
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"quarters-standAlone-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"timeFormat-medium": "HH:mm:ss",
	"dateFormatItem-yMMdd": "dd.MM.y",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"eraAbbr": [
		"v. Chr.",
		"n. Chr."
	],
	"field-minute": "Minute",
	"field-dayperiod": "Tageshälfte",
	"days-standAlone-abbr": [
		"So",
		"Mo",
		"Di",
		"Mi",
		"Do",
		"Fr",
		"Sa"
	],
	"dayPeriods-format-wide-night": "nachts",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "Gestern",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "Vorgestern",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d.M.",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-day": "Tag",
	"days-format-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"field-zone": "Zone",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "Letztes Jahr",
	"field-month-relative+-1": "Letzter Monat",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"eraNames": [
		"v. Chr.",
		"n. Chr."
	],
	"dateFormatItem-yMMMd": "d. MMM y",
	"days-format-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Monat",
	"dayPeriods-format-wide-am": "vorm.",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"dateFormatItem-MMMMdd": "dd. MMMM",
	"dateFormat-short": "dd.MM.yy",
	"dateFormatItem-MMd": "d.MM.",
	"dayPeriods-format-wide-afternoon": "nachmittags",
	"field-second": "Sekunde",
	"dateFormatItem-yMMMEd": "E, d. MMM y",
	"field-month-relative+0": "Dieser Monat",
	"field-month-relative+1": "Nächster Monat",
	"dateFormatItem-Ed": "E, d.",
	"field-week": "Woche",
	"dateFormat-medium": "dd.MM.y",
	"field-year-relative+0": "Dieses Jahr",
	"field-week-relative+-1": "Letzte Woche",
	"field-year-relative+1": "Nächstes Jahr",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-week-relative+0": "Diese Woche",
	"field-week-relative+1": "Nächste Woche"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/de/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "jetzt",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Wochentag",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E, d.M.y",
	"field-wed-relative+0": "diesen Mittwoch",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-wed-relative+1": "nächsten Mittwoch",
	"eraNarrow": [
		"v. Chr.",
		"v. u. Z.",
		"n. Chr.",
		"u. Z."
	],
	"dateFormatItem-yMM": "MM.y",
	"dayPeriods-format-wide-earlyMorning": "morgens",
	"field-tue-relative+-1": "letzten Dienstag",
	"dayPeriods-format-wide-morning": "vormittags",
	"days-format-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"dateFormat-long": "d. MMMM y",
	"field-fri-relative+-1": "letzten Freitag",
	"field-wed-relative+-1": "letzten Mittwoch",
	"months-format-wide": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember"
	],
	"dayPeriods-format-wide-evening": "abends",
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "nachm.",
	"dateFormat-full": "EEEE, d. MMMM y",
	"field-thu-relative+-1": "letzten Donnerstag",
	"dateFormatItem-Md": "d.M.",
	"dayPeriods-format-wide-noon": "mittags",
	"dateFormatItem-yMd": "d.M.y",
	"dateFormatItem-yM": "M.y",
	"field-era": "Epoche",
	"months-standAlone-wide": [
		"Januar",
		"Februar",
		"März",
		"April",
		"Mai",
		"Juni",
		"Juli",
		"August",
		"September",
		"Oktober",
		"November",
		"Dezember"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"timeFormat-long": "HH:mm:ss z",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-year": "Jahr",
	"dateFormatItem-MMdd": "dd.MM.",
	"field-hour": "Stunde",
	"months-format-abbr": [
		"Jan.",
		"Feb.",
		"März",
		"Apr.",
		"Mai",
		"Juni",
		"Juli",
		"Aug.",
		"Sep.",
		"Okt.",
		"Nov.",
		"Dez."
	],
	"field-sat-relative+0": "diesen Samstag",
	"field-sat-relative+1": "nächsten Samstag",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "heute",
	"field-day-relative+1": "morgen",
	"field-thu-relative+0": "diesen Donnerstag",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "übermorgen",
	"field-thu-relative+1": "nächsten Donnerstag",
	"dateFormatItem-H": "HH 'Uhr'",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mär",
		"Apr",
		"Mai",
		"Jun",
		"Jul",
		"Aug",
		"Sep",
		"Okt",
		"Nov",
		"Dez"
	],
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"quarters-standAlone-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"timeFormat-medium": "HH:mm:ss",
	"dateFormatItem-yMMdd": "dd.MM.y",
	"field-sun-relative+0": "diesen Sonntag",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-sun-relative+1": "nächsten Sonntag",
	"eraAbbr": [
		"v. Chr.",
		"n. Chr."
	],
	"field-minute": "Minute",
	"field-dayperiod": "Tageshälfte",
	"days-standAlone-abbr": [
		"So",
		"Mo",
		"Di",
		"Mi",
		"Do",
		"Fr",
		"Sa"
	],
	"dayPeriods-format-wide-night": "nachts",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "gestern",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} 'um' {0}",
	"field-day-relative+-2": "vorgestern",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d.M.",
	"dateTimeFormat-full": "{1} 'um' {0}",
	"field-fri-relative+0": "diesen Freitag",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-fri-relative+1": "nächsten Freitag",
	"field-day": "Tag",
	"days-format-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"field-zone": "Zeitzone",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "letztes Jahr",
	"field-month-relative+-1": "letzten Monat",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"eraNames": [
		"v. Chr.",
		"n. Chr."
	],
	"dateFormatItem-yMMMd": "d. MMM y",
	"days-format-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Monat",
	"field-tue-relative+0": "diesen Dienstag",
	"field-tue-relative+1": "nächsten Dienstag",
	"dayPeriods-format-wide-am": "vorm.",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"dateFormatItem-EHm": "E, HH:mm",
	"field-mon-relative+0": "diesen Montag",
	"field-mon-relative+1": "nächsten Montag",
	"dateFormat-short": "dd.MM.yy",
	"dateFormatItem-MMd": "d.MM.",
	"dayPeriods-format-wide-afternoon": "nachmittags",
	"dateFormatItem-EHms": "E, HH:mm:ss",
	"dateFormatItem-Ehms": "E, h:mm:ss a",
	"field-second": "Sekunde",
	"field-sat-relative+-1": "letzten Samstag",
	"dateFormatItem-yMMMEd": "E, d. MMM y",
	"field-sun-relative+-1": "letzten Sonntag",
	"field-month-relative+0": "diesen Monat",
	"field-month-relative+1": "nächsten Monat",
	"dateFormatItem-Ed": "E, d.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Woche",
	"dateFormat-medium": "dd.MM.y",
	"field-year-relative+0": "dieses Jahr",
	"field-week-relative+-1": "letzte Woche",
	"field-year-relative+1": "nächstes Jahr",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "letzten Montag",
	"field-week-relative+0": "diese Woche",
	"field-week-relative+1": "nächste Woche"
}
//end v1.x content
);
